@@ -20,9 +20,9 @@
 #ifndef DOLPHIN_TAB_PAGE_H
 #define DOLPHIN_TAB_PAGE_H
 
-#include <QWidget>
 #include <QPointer>
 #include <QUrl>
+#include <QWidget>
 
 class QSplitter;
 class DolphinViewContainer;
@@ -33,7 +33,7 @@ class DolphinTabPage : public QWidget
     Q_OBJECT
 
 public:
-    explicit DolphinTabPage(const QUrl& primaryUrl, const QUrl& secondaryUrl = QUrl(), QWidget* parent = 0);
+    explicit DolphinTabPage(const QUrl& primaryUrl, const QUrl& secondaryUrl = QUrl(), QWidget* parent = nullptr);
 
     /**
      * @return True if primary view is the active view in this tab.
