@@ -19,18 +19,17 @@
 
 #include "kfileitemlistview.h"
 
-#include "kfileitemmodelrolesupdater.h"
 #include "kfileitemlistwidget.h"
 #include "kfileitemmodel.h"
+#include "kfileitemmodelrolesupdater.h"
 #include "private/kpixmapmodifier.h"
 
-#include <QIcon>
 #include <KIconLoader>
 
-#include <QPainter>
-#include <QTimer>
 #include <QGraphicsScene>
 #include <QGraphicsView>
+#include <QPainter>
+#include <QTimer>
 
 // #define KFILEITEMLISTVIEW_DEBUG
 
@@ -49,9 +48,9 @@ namespace {
 
 KFileItemListView::KFileItemListView(QGraphicsWidget* parent) :
     KStandardItemListView(parent),
-    m_modelRolesUpdater(0),
-    m_updateVisibleIndexRangeTimer(0),
-    m_updateIconSizeTimer(0)
+    m_modelRolesUpdater(nullptr),
+    m_updateVisibleIndexRangeTimer(nullptr),
+    m_updateIconSizeTimer(nullptr)
 {
     setAcceptDrops(true);
 
@@ -229,7 +228,7 @@ void KFileItemListView::onModelChanged(KItemModelBase* current, KItemModelBase*
     KStandardItemListView::onModelChanged(current, previous);
 
     delete m_modelRolesUpdater;
-    m_modelRolesUpdater = 0;
+    m_modelRolesUpdater = nullptr;
 
     if (current) {
         m_modelRolesUpdater = new KFileItemModelRolesUpdater(static_cast<KFileItemModel*>(current), this);
